/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.framework;

import java.io.IOException;
import java.io.OutputStreamWriter;

/**
 *
 * @author Zdeněk Žamberský
 */
public class Shell extends org.thermostat.qa2.framework.NativeProcess {

    OutputStreamWriter osw;
    boolean startOfLine = true;

    public Shell(String... commands) {
        super(commands);
    }

    @Override
    public void start() throws IOException {
        super.start();
        osw = new OutputStreamWriter(process.getOutputStream());
        logger.setPrefix(label + " (stdin)");
    }

    private void writeImpl(String s) throws IOException {
        if (startOfLine) {
            logger.printLogPrefix();
            startOfLine = false;
        }
        logger.print(s);
        osw.write(s);
        osw.flush();
    }

    private void writelnImpl(String s) throws IOException {
        logger.log(s);
        osw.write(s + "\n");
        osw.flush();
        startOfLine = true;
    }

    public void write(String s) throws IOException {
        int oldIndex = 0;
        int newIndex;
        for (;;) {
            newIndex = s.indexOf("\n", oldIndex);
            if (newIndex < 0) {
                break;
            }
            writelnImpl(s.substring(oldIndex, newIndex));
            oldIndex = newIndex + 1;
        }
        if (oldIndex < s.length()) {
            writeImpl(s.substring(oldIndex));
        }
    }

    public void writeln(String s) throws IOException {
        write(s + '\n');
    }

    public void exit() throws IOException {
        writeln("exit");
    }

}
