/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.framework.services;

import java.util.HashMap;
import java.util.List;
import java.util.Map;
import org.thermostat.qa2.framework.NativeProcess;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.utils.CommonUtilities;

/**
 *
 * @author Zdeněk Žamberský
 */
public class GnomeKeyring extends AbstractService {

    public String configurationDirectory;
    public String keyringPassword = "123";
    public HashMap<String, String> defaultEnvironment = new HashMap();

    public GnomeKeyring() {
        this(ThermostatQAConfig.gnomeKeyringConfigDir);
    }

    public GnomeKeyring(String configurationDirectory) {
        this.configurationDirectory = configurationDirectory;
    }

    @Override
    public String getServiceName() throws Exception {
        return "Gnome keyring";
    }

    @Override
    public void startServiceImpl() throws Exception {
        setRunning(true);
        NativeProcess process;

        boolean oldKeyring = ThermostatQAConfig.isRhel6();
        process = new NativeProcess("bash", "-c", "echo -n " + keyringPassword + " | gnome-keyring-daemon --daemonize --login");
        process.setLabel(getServiceName());
        process.setStdOutMode(NativeProcess.MODE_LOG_AND_BUFFER);
        if (!oldKeyring) {
            process.setEnvironmentVariable("XDG_DATA_HOME", configurationDirectory);
        }
        process.start();
        process.waitFor();
        readEnvars(process.getStdoutLines());

        process = new NativeProcess("gnome-keyring-daemon", "--start");
        process.setLabel(getServiceName());
        process.setStdOutMode(NativeProcess.MODE_LOG_AND_BUFFER);
        if (!oldKeyring) {
            process.setEnvironmentVariable("XDG_DATA_HOME", configurationDirectory);
        }
        setEnvvars(process, defaultEnvironment);
        process.start();
        process.waitFor();
        readEnvars(process.getStdoutLines());

        process = new NativeProcess("bash", "-c", "echo -n " + keyringPassword + " | gnome-keyring-daemon --unlock");
        process.setLabel(getServiceName());
        process.setStdOutMode(NativeProcess.MODE_LOG_AND_BUFFER);
        setEnvvars(process, defaultEnvironment);
        if (!oldKeyring) {
            process.setEnvironmentVariable("XDG_DATA_HOME", configurationDirectory);
        }
        process.start();
        process.waitFor();

        CommonUtilities.sleep(2000);
    }

    public void readEnvars(List<String> lines) {
        for (String line : lines) {
            if (line.contains("=")) {
                String[] segments = line.split("=");
                defaultEnvironment.put(segments[0], segments[1]);
            }
        }
    }

    public void setEnvvars(NativeProcess process, HashMap<String, String> environment) {
        for (Map.Entry<String, String> entry : environment.entrySet()) {
            process.setEnvironmentVariable(entry.getKey(), entry.getValue());
        }
    }

    @Override
    public void stopServiceImpl() throws Exception {
        setRunning(false);
        NativeProcess process = new NativeProcess("killall", "gnome-keyring-daemon");
        process.setLabel(getServiceName());
        process.start();
        process.waitFor();
    }

}
