/*
 ThermostatQA - test framework for Thermostat Monitoring Tool

 Copyright 2015 Red Hat, Inc.

 This file is part of ThermostatQA

 ThermostatQA is distributed under the GNU General Public License,
 version 2 or any later version (with a special exception described
 below, commonly known as the "Classpath Exception").

 A copy of GNU General Public License (GPL) is included in this
 distribution, in the file COPYING.

 Linking ThermostatQA code with other modules is making a combined work
 based on ThermostatQA.  Thus, the terms and conditions of the GPL
 cover the whole combination.

 As a special exception, the copyright holders of ThermostatQA give you
 permission to link this code with independent modules to produce an
 executable, regardless of the license terms of these independent
 modules, and to copy and distribute the resulting executable under
 terms of your choice, provided that you also meet, for each linked
 independent module, the terms and conditions of the license of that
 module.  An independent module is a module which is not derived from
 or based on ThermostatQA code.  If you modify ThermostatQA, you may
 extend this exception to your version of the software, but you are
 not obligated to do so.  If you do not wish to do so, delete this
 exception statement from your version.
 */
package org.thermostat.qa2.tests;

import java.util.List;
import static org.thermostat.qa2.framework.Assert.assertTrue;
import static org.thermostat.qa2.framework.Assert.assertContainsPatterns;
import org.thermostat.qa2.framework.ThermostatQAConfig;
import org.thermostat.qa2.framework.annotations.SetupStorage;
import org.thermostat.qa2.framework.annotations.Test;
import org.thermostat.qa2.framework.services.ThermostatStorage;

/**
 * Test class ported from old framework
 * @author Zdeněk Žamberský
 */
@SetupStorage(type = "mongo")
public class StorageSmokeTest {

    public final static String[] START_PATTERNS = {
        "starting storage server...",
        "server listening on ip: mongodb://127.0.0.1:" + ThermostatQAConfig.mongoPort,
        "log file is here:",
        "pid: "
    };

    public static String[] STOP_PATTERNS = {
        "server shutdown complete: ",
        "log file is here:"
    };

    public static List<String> startStorageGetStdout() throws Exception {
        ThermostatStorage storage = new ThermostatStorage();
        storage.setStartStdoutBuffering(true);
        storage.start();
        return storage.getStartStdoutLines();
    }

    public static List<String> stopStorageGetStdout() throws Exception {
        ThermostatStorage storage = new ThermostatStorage();
        storage.setStopStdoutBuffering(true);
        storage.start();
        storage.stop();
        return storage.getStopStdoutLines();
    }

    @Test
    public void startStorageTest() throws Exception {
        List<String> stdout = startStorageGetStdout();
        assertTrue(stdout.size() > 0, "there should be stdout output on start");
    }

    @Test
    public void stopStorageTest() throws Exception {
        List<String> stdout = stopStorageGetStdout();
        assertTrue(stdout.size() > 0, "there should be stdout output on start");
    }

    @Test
    public void startStorageMessageTest() throws Exception {
        List<String> stdout = startStorageGetStdout();
        assertTrue(stdout.size() > 0, "there should be stdout output on start");
        assertContainsPatterns(stdout, START_PATTERNS);

    }

    @Test
    public void stopStorageMessageTest() throws Exception {
        List<String> stdout = stopStorageGetStdout();
        assertTrue(stdout.size() > 0, "there should be stdout output on start");
        assertContainsPatterns(stdout, STOP_PATTERNS);
    }

}
